@@ -68,7 +68,8 @@ get_SDV_legend_elements <- function(WHERE,
                                      attvalue <- data.frame(
                                        value = NA,
                                        lower_value = attr(z, 'lower_value'),
-                                       upper_value = attr(z, 'upper_value')
+                                       upper_value = attr(z, 'upper_value'),
+                                       stringsAsFactors = FALSE
                                      )
                                    }
                                    d <- data.frame(
@@ -80,18 +81,22 @@ get_SDV_legend_elements <- function(WHERE,
                                      attributedescription = x$attributedescription,
                                      nasisrulename = x$nasisrulename,
                                      label = attr(z, 'label'),
-                                     order = attr(z, 'order'))
+                                     order = attr(z, 'order'),
+                                     stringsAsFactors = FALSE
+                                   )
                                    d <- cbind(d, attvalue)
                                    d2 <- data.frame(
                                      red = attr(z$Color, 'red'),
                                      green = attr(z$Color, 'green'),
-                                     blue = attr(z$Color, 'blue')
+                                     blue = attr(z$Color, 'blue'),
+                                     stringsAsFactors = FALSE
                                    )
                                    if (nrow(d2) == 0) {
                                      d2 <- data.frame(red = NA, 
                                                       green = NA, 
                                                       blue = NA, 
-                                                      hex = notratedcolor)
+                                                      hex = notratedcolor,
+                                                      stringsAsFactors = FALSE)
                                    } else {                                      
                                      newcolor <- rgb(
                                        red = d2$red,
