@@ -660,6 +660,7 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
     dsn = 'gnatsgo',
     type = 'GEOTIFF_FLOAT',
     desc = 'gNATSGO map unit keys',
+    vintage = 'FY2024',
     na = 2147483647L,
     res = 30,
     rat = NULL
@@ -669,6 +670,7 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
     dsn = 'gssurgo',
     type = 'GEOTIFF_FLOAT',
     desc = 'gSSURGO map unit keys',
+    vintage = 'FY2024',
     na = 2147483647L,
     res = 30,
     rat = NULL
@@ -677,7 +679,8 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
   'hi_ssurgo' = list(
     dsn = 'hi_ssurgo',
     type = 'GEOTIFF_FLOAT',
-    desc = 'HI map unit keys',
+    desc = 'HI map unit keys (experimental)',
+    vintage = 'FY2024',
     na = 4294967295,
     res = 30,
     rat = NULL
@@ -686,7 +689,8 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
   'pr_ssurgo' = list(
     dsn = 'pr_ssurgo',
     type = 'GEOTIFF_FLOAT',
-    desc = 'PR map unit keys',
+    desc = 'PR map unit keys (experimental)',
+    vintage = 'FY2024',
     na = 4294967295,
     res = 30,
     rat = NULL
@@ -696,6 +700,7 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
     dsn = 'statsgo',
     type = 'GEOTIFF_FLOAT',
     desc = 'STATSGO2 map unit keys',
+    vintage = 'FY2023',
     na = 0L,
     res = 300,
     rat = NULL
@@ -705,6 +710,7 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
     dsn = 'rss',
     type = 'GEOTIFF_FLOAT',
     desc = 'RSS map unit keys',
+    vintage = 'FY2023',
     na = 0L,
     res = 10,
     rat = NULL
